TaskCoreError

Enum TaskCoreError 

pub enum TaskCoreError {
    Codec(String),
    InvalidValue(String),
    Io(String),
    LeaseLost {
        task_id: i64,
        processing_token: i64,
    },
    LeaseRenewalTimedOut {
        task_id: i64,
        processing_token: i64,
    },
    WorkerShutdownRequested {
        task_id: i64,
        processing_token: i64,
    },
}
Error returned by shared task helpers before product-level mapping.

Variants



Codec(String)

A stored task value could not be decoded or serialized.



InvalidValue(String)

A task step or registry lookup failed semantic validation.



Io(String)

Runtime filesystem work failed.



LeaseLost

The current worker lost its processing lease to another worker.

Fields

task_id: i64

Persisted task identifier.

processing_token: i64

Processing token owned by the current worker.



LeaseRenewalTimedOut

The current worker did not renew its processing lease before the safety deadline.

Fields

task_id: i64

Persisted task identifier.

processing_token: i64

Processing token owned by the current worker.



WorkerShutdownRequested

The current worker observed shutdown and should release its processing lease.

Fields

task_id: i64

Persisted task identifier.

processing_token: i64

Processing token owned by the current worker.

Implementations

Source

impl TaskCoreError

pub fn codec(message: impl Into<String>) -> Self

Creates a codec error.

pub fn invalid_value(message: impl Into<String>) -> Self

Creates an invalid-value error.

pub fn io(message: impl Into<String>) -> Self

Creates an I/O error.

pub const fn is_task_lease_lost(&self) -> bool

Returns whether this error means the current worker lost its lease.

pub const fn is_task_lease_renewal_timed_out(&self) -> bool

Returns whether this error means the current worker’s lease renewal timed out.

pub const fn is_task_worker_shutdown_requested(&self) -> bool

Returns whether this error means the current worker should stop for shutdown.