TaskRetryClass

Enum TaskRetryClass 

pub enum TaskRetryClass {
    Auto,
    Manual,
    Never,
}
Retry behavior selected after a task failure.

Variants



Auto

The dispatcher may automatically retry while the retry budget remains.



Manual

The task may be retried manually, but not automatically.



Never

The failure is permanent and must not be retried.

Implementations

Source

impl TaskRetryClass

pub const fn should_auto_retry(self) -> bool

Returns whether the class permits automatic retry.

pub const fn can_manual_retry(self) -> bool

Returns whether the class permits manual retry.