pub fn background_task_component(
background_tasks: BackgroundTasks,
) -> RuntimeComponentBundleRegistration<BackgroundTaskRuntimeComponent>Expand description
Creates the background task runtime component used by product entrypoints.
pub fn background_task_component(
background_tasks: BackgroundTasks,
) -> RuntimeComponentBundleRegistration<BackgroundTaskRuntimeComponent>Creates the background task runtime component used by product entrypoints.