pub fn decode_payload_as<S, State, Task, Config, Context, Error>(
task: &Task,
) -> Result<S::Payload>Expand description
Decodes a task payload as the typed payload for S.
Errors
Returns TaskCoreError when the stored payload is absent or cannot be decoded.