pub fn mark_active_step_failed(steps: &mut [TaskStepInfo], detail: Option<&str>)Expand description
Marks the active step failed, or the last pending step when no step is active.
pub fn mark_active_step_failed(steps: &mut [TaskStepInfo], detail: Option<&str>)Marks the active step failed, or the last pending step when no step is active.