pub fn serialize_result<S, State, Task, Config, Context, Error>(
result: &S::Result,
) -> Result<String>Expand description
Serializes a typed task result.
Errors
Returns TaskCoreError when the typed result cannot be serialized as JSON.
pub fn serialize_result<S, State, Task, Config, Context, Error>(
result: &S::Result,
) -> Result<String>Serializes a typed task result.
Returns TaskCoreError when the typed result cannot be serialized as JSON.