pub struct BackgroundTaskRuntimeDefinitionsComponentFromShutdown<Kind: 'static, PresentationCode: 'static, F> { /* private fields */ }Expand description
Runtime builder component that spawns background tasks and registers task definitions.
Implementations
Sourceimpl<Kind: 'static, PresentationCode: 'static, F> BackgroundTaskRuntimeDefinitionsComponentFromShutdown<Kind, PresentationCode, F>
impl<Kind: 'static, PresentationCode: 'static, F> BackgroundTaskRuntimeDefinitionsComponentFromShutdown<Kind, PresentationCode, F>
Sourcepub const fn new(
definitions: &'static [RuntimeTaskDefinition<Kind, PresentationCode>],
spawn: F,
) -> Self
pub const fn new( definitions: &'static [RuntimeTaskDefinition<Kind, PresentationCode>], spawn: F, ) -> Self
Creates a component from static task definitions and a worker-spawning function.