DispatchStats

Struct DispatchStats 

pub struct DispatchStats {
    pub claimed: usize,
    pub succeeded: usize,
    pub retried: usize,
    pub failed: usize,
}
Aggregate counters returned by a background task dispatch pass.

Fields

claimed: usize

Number of tasks claimed for execution.

succeeded: usize

Number of tasks completed successfully.

retried: usize

Number of tasks scheduled for retry.

failed: usize

Number of tasks permanently failed.

Implementations

Source

impl DispatchStats

pub fn add(&mut self, other: Self)

Adds another dispatch counter set into this one.

pub const fn has_activity(&self) -> bool

Returns whether any dispatch activity happened.

pub fn add_outcome(&mut self, outcome: TaskDispatchOutcome)

Adds a task execution outcome to the aggregate counters.