TaskRetryUpdate

Struct TaskRetryUpdate 

pub struct TaskRetryUpdate<'a> {
    pub attempt_count: i32,
    pub retry_at: DateTime<Utc>,
    pub storage_error: &'a str,
    pub display_error: &'a str,
    pub failed_steps_json: Option<&'a str>,
}
Retry update passed to product storage after an automatically retryable failure.

Fields

attempt_count: i32

Attempt count to persist for the just-finished execution.

retry_at: DateTime<Utc>

Timestamp when the next automatic retry should become due.

storage_error: &'a str

Truncated/storable error string.

display_error: &'a str

Human-facing error string used for logs and step details.

failed_steps_json: Option<&'a str>

Serialized task steps after marking the active step failed, if available.