pub enum TaskRetryClass {
Auto,
Manual,
Never,
}Expand description
Retry behavior selected after a task failure.
Variants
Auto
The dispatcher may automatically retry while the retry budget remains.
Manual
The task may be retried manually, but not automatically.
Never
The failure is permanent and must not be retried.
Implementations
Sourceimpl TaskRetryClass
impl TaskRetryClass
Sourcepub const fn should_auto_retry(self) -> bool
pub const fn should_auto_retry(self) -> bool
Returns whether the class permits automatic retry.
Sourcepub const fn can_manual_retry(self) -> bool
pub const fn can_manual_retry(self) -> bool
Returns whether the class permits manual retry.