pub struct DispatchStats {
pub claimed: usize,
pub succeeded: usize,
pub retried: usize,
pub failed: usize,
}Expand description
Aggregate counters returned by a background task dispatch pass.
Fields
claimed: usizeNumber of tasks claimed for execution.
succeeded: usizeNumber of tasks completed successfully.
retried: usizeNumber of tasks scheduled for retry.
failed: usizeNumber of tasks permanently failed.
Implementations
Sourceimpl DispatchStats
impl DispatchStats
Sourcepub const fn has_activity(&self) -> bool
pub const fn has_activity(&self) -> bool
Returns whether any dispatch activity happened.
Sourcepub fn add_outcome(&mut self, outcome: TaskDispatchOutcome)
pub fn add_outcome(&mut self, outcome: TaskDispatchOutcome)
Adds a task execution outcome to the aggregate counters.