pub struct TaskExecutionContext { /* private fields */ }Expand description
Task execution context passed to product task implementations.
Implementations
Sourceimpl TaskExecutionContext
impl TaskExecutionContext
Sourcepub fn new(
lease: TaskLease,
renewal_timeout: Duration,
shutdown_token: CancellationToken,
) -> Self
pub fn new( lease: TaskLease, renewal_timeout: Duration, shutdown_token: CancellationToken, ) -> Self
Creates a task execution context.
Sourcepub const fn lease_guard(&self) -> &TaskLeaseGuard
pub const fn lease_guard(&self) -> &TaskLeaseGuard
Returns the lease guard used by progress and heartbeat updates.
Sourcepub fn ensure_active(&self) -> Result<()>
pub fn ensure_active(&self) -> Result<()>
Returns success only while the worker should continue task execution.
Sourcepub async fn sleep_or_shutdown(&self, duration: Duration) -> Result<()>
pub async fn sleep_or_shutdown(&self, duration: Duration) -> Result<()>
Sleeps until duration elapses or shutdown is requested.
Sourcepub async fn shutdown_requested(&self) -> Result<()>
pub async fn shutdown_requested(&self) -> Result<()>
Waits for shutdown and then returns the shutdown-requested lease error.