TaskLeaseGuard

Struct TaskLeaseGuard 

pub struct TaskLeaseGuard { /* private fields */ }
Shared in-memory lease guard observed by task code and heartbeat code.

Implementations

Source

impl TaskLeaseGuard

pub fn new(lease: TaskLease, renewal_timeout: Duration) -> Self

Creates a guard with the provided renewal timeout.

pub fn with_shutdown_token( lease: TaskLease, renewal_timeout: Duration, shutdown_token: CancellationToken, ) -> Self

Creates a guard that also observes worker shutdown.

pub const fn lease(&self) -> TaskLease

Returns the persisted lease represented by this guard.

pub fn record_renewed(&self)

Records a successful persistent lease renewal.

pub fn mark_lost(&self) -> TaskCoreError

Marks the lease as lost and returns the corresponding error.

pub fn mark_shutdown_requested(&self) -> TaskCoreError

Marks worker shutdown and returns the corresponding error.

pub fn ensure_active(&self) -> Result<()>

Returns success only while the lease is still safe for writes.